import { BasicPageParams, BasicFetchResult } from '/@/api/model/baseModel';
export type AD_INFO = {
  nation?: string;
  province?: string;
  city?: string;
  district?: string;
  adcode?: string;
};

export type AccountInfo = {
  useR_CODE: string;
  password: string;
  ip?: string;
  ad_info?: AD_INFO;
  ORG_CODE: string;
};

export type AccountParams = BasicPageParams & {
  USER_ID: string;
  USER_NAME: string;
  deptCode: string;
};

export type RoleParams = {
  ROLE_DESC?: string;
  IS_ACTIVE?: string;
};

export type RolePageParams = BasicPageParams & RoleParams;

export type UserGPParams = {
  USERGROUP_CODE?: string;
  USERGROUP_DESC?: string;
};

export type MenuParams = {
  menuName?: string;
  status?: string;
};

export type SaveMenuParams = {
  menuName?: string;
  status?: string;
  type: string;
  parentMenu: string;
  orderNo: number;
  icon: string;
  routePath: string;
  isExt: string;
  isUpdate: boolean;
  show: string;
};

export type SaveRoleParams = {
  ROLE_DESC?: string;
  ROLE_CODE?: string;
  IS_ACTIVE?: string;
  isUpdate: boolean;
  menu: string;
};

export type DeleteMenuParams = {
  children: [];
  status: string;
  parentMenu: string;
  menuName: string;
  icon: string;
  func_type: string;
  orderNo: number;
  func_code: string;
  id: string;
  path: string;
  component: string;
  meta: {
    orderNo: 2;
    title: string;
    icon: string;
  };
  name: string;
  createTime: string;
};

export type FuncItem = {
  ID: string;
  FUNC_CODE: string;
  FUNC_NAME: string;
  FUNC_DESC: string;
  FUNC_GROUP: string;
  FUNC_TYPE: string;
  PFUNC_CODE: string;
  FUNC_CLASS: string;
  PATH: string;
  ICON_URL: string;
  SEQ_NO: number;
  IS_USE: string;
  CREATE_USER: string;
  CREATE_TIME: Date;
  UPDATE_USER: string;
  UPDATE_TIME: Date;
  COMPONENT: string;
};

export type RoleItem = {
  ID: string;
  ROLE_CODE: string;
  ROLE_DESC: string;
  IS_ACTIVE: string;
  CREATE_USER: string;
  CREATE_TIME: Date;
  UPDATE_USER: string;
  UPDATE_TIME: Date;
};

export interface AccountListItem {
  ID: string;
  USER_ID: string;
  EMAIL: string;
  USER_NAME: string;
  USER_PWD: string;
  CREATE_TIME: string;
  STATUS_CODE:any;
}

export interface UserGPListItem {
  ID: string;
  USERGROUP_CODE: string;
  USERGROUP_DESC: string;
  USERGROUP_TYPE: string;
  CREATE_TIME: string;
}

export interface MenuListItem {
  id: string;
  orderNo: string;
  createTime: string;
  status: number;
  icon: string;
  component: string;
  permission: string;
}

export interface RoleListItem {
  ID: string;
  ROLE_DESC: string;
  ROLE_CODE: string;
  HALF_CHECK: string;
  IS_ACTIVE: string;
  CREATE_TIME: string;
}

export interface RoleMenuItem {
  ROLE_CODE: string;
  FUNC_CODE: string;
  HALF_CHECK: string;
}

export interface iSYS_ROLE_ORG {
  ROLE_CODE: string;
  ORG_CODE: string;
  HALF_CHECK: string;
}

export interface iSYS_ROLE_WH {
  ROLE_CODE: string;
  WH_CODE: string;
  HALF_CHECK: string;
}

export type DeptParams = {
  deptName?: string;
  status?: number;
};
export type DeptPageParams = BasicPageParams & DeptParams;

export interface DeptListItem {
  ID: string;
  SEQ_NO: string;
  ORG_NAME: string;
  ORG_CODE: string;
  PARENT: string;
  CREATE_TIME: string;
  REMARK: string;
  STATUS: number;
}

export interface SpecificEntity {
  ID: string;
  EntityStr: string;
  UserId: string;
  Extend1: string;
  Extend2: string;
  Extend3: string;
}

export type ParamParams = {
  PARAM_CODE?: string;
  PARAM_NAME?: string;
};
export type ParamsPageParams = BasicPageParams & ParamParams;

export interface ParamsListItem {
  ID: string;
  PARAM_CODE: string;
  PARAM_NAME: string;
  PARAM_DESC: string;
  PRMG_CODE: string;
  PARAM_VALUE: string;
  DATA_1: string;
  DATA_2: string;
  DATA_3: string;
  DATA_4: string;
  CREATE_USER: string;
  UPDATE_USER: string;
  UPDATE_TIME: string;
  CREATE_TIME: string;
}

export interface ParamsGroupListItem {
  ID: string;
  PRMG_CODE: string;
  PRMG_TYPE: string;
  PRMG_DESC: string;
  CREATE_USER: string;
  UPDATE_USER: string;
  UPDATE_TIME: string;
  CREATE_TIME: string;
}

export interface treeParamsListItem {
  ID: string;
  PARAM_CODE: string;
  PARAM_NAME: string;
  PARAM_DESC: string;
  PRMG_CODE: string;
  PARAM_VALUE: string;
  DATA_1: string;
  DATA_2: string;
  DATA_3: string;
  DATA_4: string;
  PRMG_TYPE: string;
  CREATE_USER: string;
  UPDATE_USER: string;
  UPDATE_TIME: string;
  CREATE_TIME: string;
  PARAM_TYPE: string;
  children: ParamsListItem[];
}

export type LoginLogParams = {
  LOGIN_FROM?: string;
  LOGIN_TIME?: string[];
};
export type LoginLogPageParams = BasicPageParams & LoginLogParams;
export interface LoginLogListItem {
  ID: string;
  SESSION_ID: string;
  FACTORY: string;
  USER_ID: string;
  LOGIN_FROM: string;
  LOGIN_CHANNEL: string;
  LOGIN_URL: string;
  LOGIN_TIME: string;
  LOGOUT_URL: string;
  LOGOUT_TIME: string;
}
// 头部据点
export interface titleDept {
  ID: string;
  USER_ID: string;
  USER_NAME: string;
  USERGROUP_ID: string;
  USERGROUP_CODE: string;
  USERGROUP_DESC: string;
  ROLE_ID: string;
  ROLE_CODE: string;
  ROLE_DESC: string;
  ORG_ID: string;
  ORG_CODE: string;
  ORG_NAME: string;
  HALF_CHECK: string;
}

/**
 * @description: Request list return value
 */

export type MenuListGetResultModel = BasicFetchResult<MenuListItem>;
export type DeptListGetResultModel = BasicFetchResult<DeptListItem>;
export type RolePageListGetResultModel = BasicFetchResult<RoleListItem>;
export type RoleListGetResultModel = RoleListItem[];
export type ParamsListGetResultModel = BasicFetchResult<ParamsListItem>;
export type LoginLogPageListGetResultModel = BasicFetchResult<LoginLogListItem>;
